@@ -7,7 +7,7 @@ import paddlehub as hub
 
 module = hub.Module(name="xception71_imagenet")
 
-img_path = "../res/classify"
+img_path = "../res/classify/test"
 
 # set input dict
 input_dict = {
