@@ -6,7 +6,7 @@ from os import path
 import paddlehub as hub
 
 TAG_PADDLE_USE_CUDA = 'PADDLE_USE_CUDA'
-FLAG_CUDA = 1
+FLAG_CUDA = '1'
 
 _cpu_num = os.system('cat /proc/cpuinfo | grep "processor"| wc -l')
 os.system('export CPU_NUM=%d' % (_cpu_num if _cpu_num else 2))
@@ -19,6 +19,7 @@ print(':: FLAGS_eager_delete_tensor_gb: %s' % os.getenv('FLAGS_eager_delete_tens
 print(':: CUDA_VISIBLE_DEVICES: %s' % os.getenv('CUDA_VISIBLE_DEVICES'))
 
 nvidia_result = os.system('lspci |grep -i nvidia')
+
 use_cuda = os.getenv(TAG_PADDLE_USE_CUDA) == FLAG_CUDA
 print(':: IN_AI_STUDIO: %s' % use_cuda)
 
